Document

Exhibit 23
CONSENT OF INDEPENDENT REGISTERED PUBLIC ACCOUNTING FIRM
We consent to the incorporation by reference in the following Registration Statements:
(1)Registration Statement (Form S-3 No. 333-264693) and in the related Prospectuses of The Clorox Company, and
(2)Registration Statements (Form S-8 Nos. 33-56563, 33-56565, 33-41131, including post effective amendments No. 1 and No. 2, 333-16969, 333-29375, 333-44675, 333-69455, including post effective amendment No. 1, 333-86783, 333-90386, including the post effective amendment No. 1, 333-131487, 333-193913 and 333-213161) of The Clorox Company;
of our reports dated August 10, 2022, with respect to the consolidated financial statements of The Clorox Company and the effectiveness of internal control over financial reporting of The Clorox Company included in this Annual Report (Form 10-K) of The Clorox Company for the year ended June 30, 2022.
/s/ Ernst & Young LLP
San Francisco, CA
August 10, 2022